/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

interface ProjectCodeReq {
  projectCode: number
}

interface WorkflowCodeReq {
  workFlowCode: number
}

interface WorkFlowNameReq {
  workFlowName: string
}

interface WorkFlowRelationDetailListRes extends WorkflowCodeReq {
  workFlowName: string
  workFlowPublishStatus: string
  scheduleStartTime?: any
  scheduleEndTime?: any
  crontab?: any
  schedulePublishStatus: number
  sourceWorkFlowCode: string
}

interface WorkFlowRelationList {
  sourceWorkFlowCode: number
  targetWorkFlowCode: number
}

interface WorkflowRes {
  data: {
    workFlowRelationDetailList: WorkFlowRelationDetailListRes[]
    workFlowRelationList: WorkFlowRelationList[]
  }
}

interface DependentTaskReq extends WorkflowCodeReq {
  taskCode?: number
}

export {
  ProjectCodeReq,
  WorkflowCodeReq,
  WorkFlowNameReq,
  DependentTaskReq,
  WorkflowRes,
  WorkFlowRelationDetailListRes
}
